AndroidVars class

Implemented types
Implementers
Annotations
  • @JsonSerializable.new()

Constructors

AndroidVars({String? projectName, String? orgTld, String? orgDomainName, String? minSdkVersion, String? targetSdkVersion, String? compileSdkVersion, bool? enableR8, Version? kotlinVersion, String? gradleVersion})
AndroidVars.fromJson(Map<String, dynamic> json)
factory

Properties

compileSdkVersion String?
The compileSdkVersion in app/build.gradle
getter/setter pair
enableR8 bool?
android.enableR8 in gradle.properties
getter/setter pair
gradleVersion String?
The gradleVersion in gradle/wrapper
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
kotlinVersion ↔ Version?
The ext.kotlin_version string in build.gradle
getter/setter pair
minSdkVersion String?
The minSdkVersion in app/build.gradle
getter/setter pair
orgDomainName String?
The domain name part of the org name
getter/setter pair
orgTld String?
The top level domain part of the org name
getter/setter pair
projectName String?
The Flutter projectName
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
targetSdkVersion String?
The targetSdkVersion in app/build.gradle
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited